"""
Generated class for Patient. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.Address import *
from fhirmodels.R5.Attachment import *
from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.ContactPoint import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.HumanName import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Period import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Resource import *


class Contact(FhirBaseModel):
    """A contact party (e.g. guardian, partner, friend) for the patient.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept relationship: The kind of relationship
    :param HumanName name: A name associated with the contact person
    :param ContactPoint telecom: A contact detail for the person
    :param Address address: Address for the contact person
    :param str gender: male | female | other | unknown
    :param Reference organization: Organization that is associated with the contact
    :param Period period: The period during which this contact person or organization is valid to be contacted relating to this patient
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "relationship": {"class_name": "CodeableConcept", "is_contained": False},
        "name": {"class_name": "HumanName", "is_contained": False},
        "telecom": {"class_name": "ContactPoint", "is_contained": False},
        "address": {"class_name": "Address", "is_contained": False},
        "organization": {"class_name": "Reference", "is_contained": False},
        "period": {"class_name": "Period", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        relationship: list["CodeableConcept"] = None,
        name: "HumanName" = None,
        telecom: list["ContactPoint"] = None,
        address: "Address" = None,
        gender: "str" = None,
        organization: "Reference" = None,
        period: "Period" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.relationship = relationship or []
        self.name = name
        self.telecom = telecom or []
        self.address = address
        self.gender = gender
        self.organization = organization
        self.period = period

    @classmethod
    def from_dict(cls, data: dict) -> "Patient":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Patient":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Communication(FhirBaseModel):
    """A language which may be used to communicate with the patient about his or her health.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept language: The language which can be used to communicate with the patient about his or her health
    :param bool preferred: Language preference indicator
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "language": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        language: "CodeableConcept" = None,
        preferred: "bool" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.language = language
        self.preferred = preferred

    @classmethod
    def from_dict(cls, data: dict) -> "Patient":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Patient":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Link(FhirBaseModel):
    """Link to a Patient or RelatedPerson resource that concerns the same actual individual.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Reference other: The other patient or related person resource that the link refers to
    :param str type: replaced-by | replaces | refer | seealso
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "other": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        other: "Reference" = None,
        type: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.other = other
        self.type = type

    @classmethod
    def from_dict(cls, data: dict) -> "Patient":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Patient":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Patient(DomainResource):
    """Demographics and other administrative information about an individual or animal receiving care or other health-related services.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: An identifier for this patient
    :param bool active: Whether this patient's record is in active use
    :param HumanName name: A name associated with the patient
    :param ContactPoint telecom: A contact detail for the individual
    :param str gender: male | female | other | unknown
    :param str birthDate: The date of birth for the individual
    :param bool deceasedBoolean: Indicates if the individual is deceased or not
    :param str deceasedDateTime: Indicates if the individual is deceased or not
    :param Address address: An address for the individual
    :param CodeableConcept maritalStatus: Marital (civil) status of a patient
    :param bool multipleBirthBoolean: Whether patient is part of a multiple birth
    :param int multipleBirthInteger: Whether patient is part of a multiple birth
    :param Attachment photo: Image of the patient
    :param Contact contact: A contact party (e.g. guardian, partner, friend) for the patient
    :param Communication communication: A language which may be used to communicate with the patient about his or her health
    :param Reference generalPractitioner: Patient's nominated primary care provider
    :param Reference managingOrganization: Organization that is the custodian of the patient record
    :param Link link: Link to a Patient or RelatedPerson resource that concerns the same actual individual
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "name": {"class_name": "HumanName", "is_contained": False},
        "telecom": {"class_name": "ContactPoint", "is_contained": False},
        "address": {"class_name": "Address", "is_contained": False},
        "maritalStatus": {"class_name": "CodeableConcept", "is_contained": False},
        "photo": {"class_name": "Attachment", "is_contained": False},
        "contact": {"class_name": "Contact", "is_contained": True},
        "communication": {"class_name": "Communication", "is_contained": True},
        "generalPractitioner": {"class_name": "Reference", "is_contained": False},
        "managingOrganization": {"class_name": "Reference", "is_contained": False},
        "link": {"class_name": "Link", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        active: "bool" = None,
        name: list["HumanName"] = None,
        telecom: list["ContactPoint"] = None,
        gender: "str" = None,
        birthDate: "str" = None,
        deceasedBoolean: "bool" = None,
        deceasedDateTime: "str" = None,
        address: list["Address"] = None,
        maritalStatus: "CodeableConcept" = None,
        multipleBirthBoolean: "bool" = None,
        multipleBirthInteger: "int" = None,
        photo: list["Attachment"] = None,
        contact: list["Contact"] = None,
        communication: list["Communication"] = None,
        generalPractitioner: list["Reference"] = None,
        managingOrganization: "Reference" = None,
        link: list["Link"] = None,
    ):

        self.resourceType = "Patient"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.active = active
        self.name = name or []
        self.telecom = telecom or []
        self.gender = gender
        self.birthDate = birthDate
        self.deceasedBoolean = deceasedBoolean
        self.deceasedDateTime = deceasedDateTime
        self.address = address or []
        self.maritalStatus = maritalStatus
        self.multipleBirthBoolean = multipleBirthBoolean
        self.multipleBirthInteger = multipleBirthInteger
        self.photo = photo or []
        self.contact = contact or []
        self.communication = communication or []
        self.generalPractitioner = generalPractitioner or []
        self.managingOrganization = managingOrganization
        self.link = link or []

    @classmethod
    def from_dict(cls, data: dict) -> "Patient":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Patient":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Address. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.generator import FhirBaseModel
from fhirmodels.R4.Extension import *
from fhirmodels.R4.Period import *


class Address(FhirBaseModel):
    """Base StructureDefinition for Address Type: An address expressed using postal conventions (as opposed to GPS or other location definition formats).  This data type may be used to convey addresses for use in delivering mail as well as for visiting locations which might not be valid for mail delivery.  There are a variety of postal address formats defined around the world.
    :param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param str use: home | work | temp | old | billing - purpose of this address
    :param str type: postal | physical | both
    :param str text: Text representation of the address
    :param str line: Street name, number, direction & P.O. Box etc.
    :param str city: Name of city, town etc.
    :param str district: District name (aka county)
    :param str state: Sub-unit of country (abbreviations ok)
    :param str postalCode: Postal code for area
    :param str country: Country (e.g. can be ISO 3166 2 or 3 letter code)
    :param Period period: Time period when address was/is in use
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "period": {"class_name": "Period", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        use: "str" = None,
        type: "str" = None,
        text: "str" = None,
        line: list["str"] = None,
        city: "str" = None,
        district: "str" = None,
        state: "str" = None,
        postalCode: "str" = None,
        country: "str" = None,
        period: "Period" = None,
    ):

        self.id = id
        self.extension = extension or []
        self.use = use
        self.type = type
        self.text = text
        self.line = line or []
        self.city = city
        self.district = district
        self.state = state
        self.postalCode = postalCode
        self.country = country
        self.period = period

    @classmethod
    def from_dict(cls, data: dict) -> "Address":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Address":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for ElementDefinition. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.generator import FhirBaseModel
from fhirmodels.R4B.Address import *
from fhirmodels.R4B.Age import *
from fhirmodels.R4B.Annotation import *
from fhirmodels.R4B.Attachment import *
from fhirmodels.R4B.CodeableConcept import *
from fhirmodels.R4B.CodeableReference import *
from fhirmodels.R4B.Coding import *
from fhirmodels.R4B.ContactDetail import *
from fhirmodels.R4B.ContactPoint import *
from fhirmodels.R4B.Contributor import *
from fhirmodels.R4B.Count import *
from fhirmodels.R4B.DataRequirement import *
from fhirmodels.R4B.Distance import *
from fhirmodels.R4B.Dosage import *
from fhirmodels.R4B.Duration import *
from fhirmodels.R4B.Element import *
from fhirmodels.R4B.Expression import *
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.HumanName import *
from fhirmodels.R4B.Identifier import *
from fhirmodels.R4B.Money import *
from fhirmodels.R4B.ParameterDefinition import *
from fhirmodels.R4B.Period import *
from fhirmodels.R4B.Quantity import *
from fhirmodels.R4B.Range import *
from fhirmodels.R4B.Ratio import *
from fhirmodels.R4B.RatioRange import *
from fhirmodels.R4B.Reference import *
from fhirmodels.R4B.RelatedArtifact import *
from fhirmodels.R4B.SampledData import *
from fhirmodels.R4B.Signature import *
from fhirmodels.R4B.Timing import *
from fhirmodels.R4B.TriggerDefinition import *
from fhirmodels.R4B.UsageContext import *


class Discriminator(FhirBaseModel):
    """Designates which child elements are used to discriminate between the slices when processing an instance. If one or more discriminators are provided, the value of the child elements in the instance data SHALL completely distinguish which slice the element in the resource matches based on the allowed values for those elements in each of the slices.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param str type: value | exists | pattern | type | profile
    :param str path: Path to element value
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        type: "str" = None,
        path: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.type = type
        self.path = path

    @classmethod
    def from_dict(cls, data: dict) -> "ElementDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ElementDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Slicing(FhirBaseModel):
    """Indicates that the element is sliced into a set of alternative definitions (i.e. in a structure definition, there are multiple different constraints on a single element in the base resource). Slicing can be used in any resource that has cardinality ..* on the base resource, or any resource with a choice of types. The set of slices is any elements that come after this in the element sequence that have the same path, until a shorter path occurs (the shorter path terminates the set).:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Discriminator discriminator: Element values that are used to distinguish the slices
    :param str description: Text description of how slicing works (or not)
    :param bool ordered: If elements must be in same order as slices
    :param str rules: closed | open | openAtEnd
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "discriminator": {"class_name": "Discriminator", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        discriminator: list["Discriminator"] = None,
        description: "str" = None,
        ordered: "bool" = None,
        rules: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.discriminator = discriminator or []
        self.description = description
        self.ordered = ordered
        self.rules = rules

    @classmethod
    def from_dict(cls, data: dict) -> "ElementDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ElementDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Base(FhirBaseModel):
    """Information about the base definition of the element, provided to make it unnecessary for tools to trace the deviation of the element through the derived and related profiles. When the element definition is not the original definition of an element - i.g. either in a constraint on another type, or for elements from a super type in a snap shot - then the information in provided in the element definition may be different to the base definition. On the original definition of the element, it will be same.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param str path: Path that identifies the base element
    :param int min: Min cardinality of the base element
    :param str max: Max cardinality of the base element
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        path: "str" = None,
        min: "int" = None,
        max: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.path = path
        self.min = min
        self.max = max

    @classmethod
    def from_dict(cls, data: dict) -> "ElementDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ElementDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Type(FhirBaseModel):
    """The data type or resource that the value of this element is permitted to be.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param str code: Data type or Resource (reference to definition)
    :param str profile: Profiles (StructureDefinition or IG) - one must apply
    :param str targetProfile: Profile (StructureDefinition or IG) on the Reference/canonical target - one must apply
    :param str aggregation: contained | referenced | bundled - how aggregated
    :param str versioning: either | independent | specific
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        code: "str" = None,
        profile: list["str"] = None,
        targetProfile: list["str"] = None,
        aggregation: list["str"] = None,
        versioning: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.code = code
        self.profile = profile or []
        self.targetProfile = targetProfile or []
        self.aggregation = aggregation or []
        self.versioning = versioning

    @classmethod
    def from_dict(cls, data: dict) -> "ElementDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ElementDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Example(FhirBaseModel):
    """A sample value for this element demonstrating the type of information that would typically be found in the element.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param str label: Describes the purpose of this example
    :param str valueBase64Binary: Value of Example (one of allowed types)
    :param bool valueBoolean: Value of Example (one of allowed types)
    :param str valueCanonical: Value of Example (one of allowed types)
    :param str valueCode: Value of Example (one of allowed types)
    :param str valueDate: Value of Example (one of allowed types)
    :param str valueDateTime: Value of Example (one of allowed types)
    :param float valueDecimal: Value of Example (one of allowed types)
    :param str valueId: Value of Example (one of allowed types)
    :param str valueInstant: Value of Example (one of allowed types)
    :param int valueInteger: Value of Example (one of allowed types)
    :param str valueMarkdown: Value of Example (one of allowed types)
    :param str valueOid: Value of Example (one of allowed types)
    :param int valuePositiveInt: Value of Example (one of allowed types)
    :param str valueString: Value of Example (one of allowed types)
    :param str valueTime: Value of Example (one of allowed types)
    :param int valueUnsignedInt: Value of Example (one of allowed types)
    :param str valueUri: Value of Example (one of allowed types)
    :param str valueUrl: Value of Example (one of allowed types)
    :param str valueUuid: Value of Example (one of allowed types)
    :param Address valueAddress: Value of Example (one of allowed types)
    :param Age valueAge: Value of Example (one of allowed types)
    :param Annotation valueAnnotation: Value of Example (one of allowed types)
    :param Attachment valueAttachment: Value of Example (one of allowed types)
    :param CodeableConcept valueCodeableConcept: Value of Example (one of allowed types)
    :param CodeableReference valueCodeableReference: Value of Example (one of allowed types)
    :param Coding valueCoding: Value of Example (one of allowed types)
    :param ContactPoint valueContactPoint: Value of Example (one of allowed types)
    :param Count valueCount: Value of Example (one of allowed types)
    :param Distance valueDistance: Value of Example (one of allowed types)
    :param Duration valueDuration: Value of Example (one of allowed types)
    :param HumanName valueHumanName: Value of Example (one of allowed types)
    :param Identifier valueIdentifier: Value of Example (one of allowed types)
    :param Money valueMoney: Value of Example (one of allowed types)
    :param Period valuePeriod: Value of Example (one of allowed types)
    :param Quantity valueQuantity: Value of Example (one of allowed types)
    :param Range valueRange: Value of Example (one of allowed types)
    :param Ratio valueRatio: Value of Example (one of allowed types)
    :param RatioRange valueRatioRange: Value of Example (one of allowed types)
    :param Reference valueReference: Value of Example (one of allowed types)
    :param SampledData valueSampledData: Value of Example (one of allowed types)
    :param Signature valueSignature: Value of Example (one of allowed types)
    :param Timing valueTiming: Value of Example (one of allowed types)
    :param ContactDetail valueContactDetail: Value of Example (one of allowed types)
    :param Contributor valueContributor: Value of Example (one of allowed types)
    :param DataRequirement valueDataRequirement: Value of Example (one of allowed types)
    :param Expression valueExpression: Value of Example (one of allowed types)
    :param ParameterDefinition valueParameterDefinition: Value of Example (one of allowed types)
    :param RelatedArtifact valueRelatedArtifact: Value of Example (one of allowed types)
    :param TriggerDefinition valueTriggerDefinition: Value of Example (one of allowed types)
    :param UsageContext valueUsageContext: Value of Example (one of allowed types)
    :param Dosage valueDosage: Value of Example (one of allowed types)
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "valueAddress": {"class_name": "Address", "is_contained": False},
        "valueAge": {"class_name": "Age", "is_contained": False},
        "valueAnnotation": {"class_name": "Annotation", "is_contained": False},
        "valueAttachment": {"class_name": "Attachment", "is_contained": False},
        "valueCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "valueCodeableReference": {
            "class_name": "CodeableReference",
            "is_contained": False,
        },
        "valueCoding": {"class_name": "Coding", "is_contained": False},
        "valueContactPoint": {"class_name": "ContactPoint", "is_contained": False},
        "valueCount": {"class_name": "Count", "is_contained": False},
        "valueDistance": {"class_name": "Distance", "is_contained": False},
        "valueDuration": {"class_name": "Duration", "is_contained": False},
        "valueHumanName": {"class_name": "HumanName", "is_contained": False},
        "valueIdentifier": {"class_name": "Identifier", "is_contained": False},
        "valueMoney": {"class_name": "Money", "is_contained": False},
        "valuePeriod": {"class_name": "Period", "is_contained": False},
        "valueQuantity": {"class_name": "Quantity", "is_contained": False},
        "valueRange": {"class_name": "Range", "is_contained": False},
        "valueRatio": {"class_name": "Ratio", "is_contained": False},
        "valueRatioRange": {"class_name": "RatioRange", "is_contained": False},
        "valueReference": {"class_name": "Reference", "is_contained": False},
        "valueSampledData": {"class_name": "SampledData", "is_contained": False},
        "valueSignature": {"class_name": "Signature", "is_contained": False},
        "valueTiming": {"class_name": "Timing", "is_contained": False},
        "valueContactDetail": {"class_name": "ContactDetail", "is_contained": False},
        "valueContributor": {"class_name": "Contributor", "is_contained": False},
        "valueDataRequirement": {
            "class_name": "DataRequirement",
            "is_contained": False,
        },
        "valueExpression": {"class_name": "Expression", "is_contained": False},
        "valueParameterDefinition": {
            "class_name": "ParameterDefinition",
            "is_contained": False,
        },
        "valueRelatedArtifact": {
            "class_name": "RelatedArtifact",
            "is_contained": False,
        },
        "valueTriggerDefinition": {
            "class_name": "TriggerDefinition",
            "is_contained": False,
        },
        "valueUsageContext": {"class_name": "UsageContext", "is_contained": False},
        "valueDosage": {"class_name": "Dosage", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        label: "str" = None,
        valueBase64Binary: "str" = None,
        valueBoolean: "bool" = None,
        valueCanonical: "str" = None,
        valueCode: "str" = None,
        valueDate: "str" = None,
        valueDateTime: "str" = None,
        valueDecimal: "float" = None,
        valueId: "str" = None,
        valueInstant: "str" = None,
        valueInteger: "int" = None,
        valueMarkdown: "str" = None,
        valueOid: "str" = None,
        valuePositiveInt: "int" = None,
        valueString: "str" = None,
        valueTime: "str" = None,
        valueUnsignedInt: "int" = None,
        valueUri: "str" = None,
        valueUrl: "str" = None,
        valueUuid: "str" = None,
        valueAddress: "Address" = None,
        valueAge: "Age" = None,
        valueAnnotation: "Annotation" = None,
        valueAttachment: "Attachment" = None,
        valueCodeableConcept: "CodeableConcept" = None,
        valueCodeableReference: "CodeableReference" = None,
        valueCoding: "Coding" = None,
        valueContactPoint: "ContactPoint" = None,
        valueCount: "Count" = None,
        valueDistance: "Distance" = None,
        valueDuration: "Duration" = None,
        valueHumanName: "HumanName" = None,
        valueIdentifier: "Identifier" = None,
        valueMoney: "Money" = None,
        valuePeriod: "Period" = None,
        valueQuantity: "Quantity" = None,
        valueRange: "Range" = None,
        valueRatio: "Ratio" = None,
        valueRatioRange: "RatioRange" = None,
        valueReference: "Reference" = None,
        valueSampledData: "SampledData" = None,
        valueSignature: "Signature" = None,
        valueTiming: "Timing" = None,
        valueContactDetail: "ContactDetail" = None,
        valueContributor: "Contributor" = None,
        valueDataRequirement: "DataRequirement" = None,
        valueExpression: "Expression" = None,
        valueParameterDefinition: "ParameterDefinition" = None,
        valueRelatedArtifact: "RelatedArtifact" = None,
        valueTriggerDefinition: "TriggerDefinition" = None,
        valueUsageContext: "UsageContext" = None,
        valueDosage: "Dosage" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.label = label
        self.valueBase64Binary = valueBase64Binary
        self.valueBoolean = valueBoolean
        self.valueCanonical = valueCanonical
        self.valueCode = valueCode
        self.valueDate = valueDate
        self.valueDateTime = valueDateTime
        self.valueDecimal = valueDecimal
        self.valueId = valueId
        self.valueInstant = valueInstant
        self.valueInteger = valueInteger
        self.valueMarkdown = valueMarkdown
        self.valueOid = valueOid
        self.valuePositiveInt = valuePositiveInt
        self.valueString = valueString
        self.valueTime = valueTime
        self.valueUnsignedInt = valueUnsignedInt
        self.valueUri = valueUri
        self.valueUrl = valueUrl
        self.valueUuid = valueUuid
        self.valueAddress = valueAddress
        self.valueAge = valueAge
        self.valueAnnotation = valueAnnotation
        self.valueAttachment = valueAttachment
        self.valueCodeableConcept = valueCodeableConcept
        self.valueCodeableReference = valueCodeableReference
        self.valueCoding = valueCoding
        self.valueContactPoint = valueContactPoint
        self.valueCount = valueCount
        self.valueDistance = valueDistance
        self.valueDuration = valueDuration
        self.valueHumanName = valueHumanName
        self.valueIdentifier = valueIdentifier
        self.valueMoney = valueMoney
        self.valuePeriod = valuePeriod
        self.valueQuantity = valueQuantity
        self.valueRange = valueRange
        self.valueRatio = valueRatio
        self.valueRatioRange = valueRatioRange
        self.valueReference = valueReference
        self.valueSampledData = valueSampledData
        self.valueSignature = valueSignature
        self.valueTiming = valueTiming
        self.valueContactDetail = valueContactDetail
        self.valueContributor = valueContributor
        self.valueDataRequirement = valueDataRequirement
        self.valueExpression = valueExpression
        self.valueParameterDefinition = valueParameterDefinition
        self.valueRelatedArtifact = valueRelatedArtifact
        self.valueTriggerDefinition = valueTriggerDefinition
        self.valueUsageContext = valueUsageContext
        self.valueDosage = valueDosage

    @classmethod
    def from_dict(cls, data: dict) -> "ElementDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ElementDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Constraint(FhirBaseModel):
    """Formal constraints such as co-occurrence and other constraints that can be computationally evaluated within the context of the instance.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param str key: Target of 'condition' reference above
    :param str requirements: Why this constraint is necessary or appropriate
    :param str severity: error | warning
    :param str human: Human description of constraint
    :param str expression: FHIRPath expression of constraint
    :param str xpath: XPath expression of constraint
    :param str source: Reference to original source of constraint
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        key: "str" = None,
        requirements: "str" = None,
        severity: "str" = None,
        human: "str" = None,
        expression: "str" = None,
        xpath: "str" = None,
        source: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.key = key
        self.requirements = requirements
        self.severity = severity
        self.human = human
        self.expression = expression
        self.xpath = xpath
        self.source = source

    @classmethod
    def from_dict(cls, data: dict) -> "ElementDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ElementDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Binding(FhirBaseModel):
    """Binds to a value set if this element is coded (code, Coding, CodeableConcept, Quantity), or the data types (string, uri).:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param str strength: required | extensible | preferred | example
    :param str description: Human explanation of the value set
    :param str valueSet: Source of value set
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        strength: "str" = None,
        description: "str" = None,
        valueSet: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.strength = strength
        self.description = description
        self.valueSet = valueSet

    @classmethod
    def from_dict(cls, data: dict) -> "ElementDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ElementDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Mapping(FhirBaseModel):
    """Identifies a concept from an external specification that roughly corresponds to this element.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param str identity: Reference to mapping declaration
    :param str language: Computable language of mapping
    :param str map: Details of the mapping
    :param str comment: Comments about the mapping or its use
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        identity: "str" = None,
        language: "str" = None,
        map: "str" = None,
        comment: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.identity = identity
        self.language = language
        self.map = map
        self.comment = comment

    @classmethod
    def from_dict(cls, data: dict) -> "ElementDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ElementDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ElementDefinition(FhirBaseModel):
    """Base StructureDefinition for ElementDefinition Type: Captures constraints on each element within the resource, profile, or extension.
    :param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str path: Path of the element in the hierarchy of elements
    :param str representation: xmlAttr | xmlText | typeAttr | cdaText | xhtml
    :param str sliceName: Name for this particular element (in a set of slices)
    :param bool sliceIsConstraining: If this slice definition constrains an inherited slice definition (or not)
    :param str label: Name for element to display with or prompt for element
    :param Coding code: Corresponding codes in terminologies
    :param Slicing slicing: This element is sliced - slices follow
    :param str short: Concise definition for space-constrained presentation
    :param str definition: Full formal definition as narrative text
    :param str comment: Comments about the use of this element
    :param str requirements: Why this resource has been created
    :param str alias: Other names
    :param int min: Minimum Cardinality
    :param str max: Maximum Cardinality (a number or *)
    :param Base base: Base definition information for tools
    :param str contentReference: Reference to definition of content for the element
    :param Type type: Data type and Profile for this element
    :param str defaultValueBase64Binary: Specified value if missing from instance
    :param bool defaultValueBoolean: Specified value if missing from instance
    :param str defaultValueCanonical: Specified value if missing from instance
    :param str defaultValueCode: Specified value if missing from instance
    :param str defaultValueDate: Specified value if missing from instance
    :param str defaultValueDateTime: Specified value if missing from instance
    :param float defaultValueDecimal: Specified value if missing from instance
    :param str defaultValueId: Specified value if missing from instance
    :param str defaultValueInstant: Specified value if missing from instance
    :param int defaultValueInteger: Specified value if missing from instance
    :param str defaultValueMarkdown: Specified value if missing from instance
    :param str defaultValueOid: Specified value if missing from instance
    :param int defaultValuePositiveInt: Specified value if missing from instance
    :param str defaultValueString: Specified value if missing from instance
    :param str defaultValueTime: Specified value if missing from instance
    :param int defaultValueUnsignedInt: Specified value if missing from instance
    :param str defaultValueUri: Specified value if missing from instance
    :param str defaultValueUrl: Specified value if missing from instance
    :param str defaultValueUuid: Specified value if missing from instance
    :param Address defaultValueAddress: Specified value if missing from instance
    :param Age defaultValueAge: Specified value if missing from instance
    :param Annotation defaultValueAnnotation: Specified value if missing from instance
    :param Attachment defaultValueAttachment: Specified value if missing from instance
    :param CodeableConcept defaultValueCodeableConcept: Specified value if missing from instance
    :param CodeableReference defaultValueCodeableReference: Specified value if missing from instance
    :param Coding defaultValueCoding: Specified value if missing from instance
    :param ContactPoint defaultValueContactPoint: Specified value if missing from instance
    :param Count defaultValueCount: Specified value if missing from instance
    :param Distance defaultValueDistance: Specified value if missing from instance
    :param Duration defaultValueDuration: Specified value if missing from instance
    :param HumanName defaultValueHumanName: Specified value if missing from instance
    :param Identifier defaultValueIdentifier: Specified value if missing from instance
    :param Money defaultValueMoney: Specified value if missing from instance
    :param Period defaultValuePeriod: Specified value if missing from instance
    :param Quantity defaultValueQuantity: Specified value if missing from instance
    :param Range defaultValueRange: Specified value if missing from instance
    :param Ratio defaultValueRatio: Specified value if missing from instance
    :param RatioRange defaultValueRatioRange: Specified value if missing from instance
    :param Reference defaultValueReference: Specified value if missing from instance
    :param SampledData defaultValueSampledData: Specified value if missing from instance
    :param Signature defaultValueSignature: Specified value if missing from instance
    :param Timing defaultValueTiming: Specified value if missing from instance
    :param ContactDetail defaultValueContactDetail: Specified value if missing from instance
    :param Contributor defaultValueContributor: Specified value if missing from instance
    :param DataRequirement defaultValueDataRequirement: Specified value if missing from instance
    :param Expression defaultValueExpression: Specified value if missing from instance
    :param ParameterDefinition defaultValueParameterDefinition: Specified value if missing from instance
    :param RelatedArtifact defaultValueRelatedArtifact: Specified value if missing from instance
    :param TriggerDefinition defaultValueTriggerDefinition: Specified value if missing from instance
    :param UsageContext defaultValueUsageContext: Specified value if missing from instance
    :param Dosage defaultValueDosage: Specified value if missing from instance
    :param str meaningWhenMissing: Implicit meaning when this element is missing
    :param str orderMeaning: What the order of the elements means
    :param str fixedBase64Binary: Value must be exactly this
    :param bool fixedBoolean: Value must be exactly this
    :param str fixedCanonical: Value must be exactly this
    :param str fixedCode: Value must be exactly this
    :param str fixedDate: Value must be exactly this
    :param str fixedDateTime: Value must be exactly this
    :param float fixedDecimal: Value must be exactly this
    :param str fixedId: Value must be exactly this
    :param str fixedInstant: Value must be exactly this
    :param int fixedInteger: Value must be exactly this
    :param str fixedMarkdown: Value must be exactly this
    :param str fixedOid: Value must be exactly this
    :param int fixedPositiveInt: Value must be exactly this
    :param str fixedString: Value must be exactly this
    :param str fixedTime: Value must be exactly this
    :param int fixedUnsignedInt: Value must be exactly this
    :param str fixedUri: Value must be exactly this
    :param str fixedUrl: Value must be exactly this
    :param str fixedUuid: Value must be exactly this
    :param Address fixedAddress: Value must be exactly this
    :param Age fixedAge: Value must be exactly this
    :param Annotation fixedAnnotation: Value must be exactly this
    :param Attachment fixedAttachment: Value must be exactly this
    :param CodeableConcept fixedCodeableConcept: Value must be exactly this
    :param CodeableReference fixedCodeableReference: Value must be exactly this
    :param Coding fixedCoding: Value must be exactly this
    :param ContactPoint fixedContactPoint: Value must be exactly this
    :param Count fixedCount: Value must be exactly this
    :param Distance fixedDistance: Value must be exactly this
    :param Duration fixedDuration: Value must be exactly this
    :param HumanName fixedHumanName: Value must be exactly this
    :param Identifier fixedIdentifier: Value must be exactly this
    :param Money fixedMoney: Value must be exactly this
    :param Period fixedPeriod: Value must be exactly this
    :param Quantity fixedQuantity: Value must be exactly this
    :param Range fixedRange: Value must be exactly this
    :param Ratio fixedRatio: Value must be exactly this
    :param RatioRange fixedRatioRange: Value must be exactly this
    :param Reference fixedReference: Value must be exactly this
    :param SampledData fixedSampledData: Value must be exactly this
    :param Signature fixedSignature: Value must be exactly this
    :param Timing fixedTiming: Value must be exactly this
    :param ContactDetail fixedContactDetail: Value must be exactly this
    :param Contributor fixedContributor: Value must be exactly this
    :param DataRequirement fixedDataRequirement: Value must be exactly this
    :param Expression fixedExpression: Value must be exactly this
    :param ParameterDefinition fixedParameterDefinition: Value must be exactly this
    :param RelatedArtifact fixedRelatedArtifact: Value must be exactly this
    :param TriggerDefinition fixedTriggerDefinition: Value must be exactly this
    :param UsageContext fixedUsageContext: Value must be exactly this
    :param Dosage fixedDosage: Value must be exactly this
    :param str patternBase64Binary: Value must have at least these property values
    :param bool patternBoolean: Value must have at least these property values
    :param str patternCanonical: Value must have at least these property values
    :param str patternCode: Value must have at least these property values
    :param str patternDate: Value must have at least these property values
    :param str patternDateTime: Value must have at least these property values
    :param float patternDecimal: Value must have at least these property values
    :param str patternId: Value must have at least these property values
    :param str patternInstant: Value must have at least these property values
    :param int patternInteger: Value must have at least these property values
    :param str patternMarkdown: Value must have at least these property values
    :param str patternOid: Value must have at least these property values
    :param int patternPositiveInt: Value must have at least these property values
    :param str patternString: Value must have at least these property values
    :param str patternTime: Value must have at least these property values
    :param int patternUnsignedInt: Value must have at least these property values
    :param str patternUri: Value must have at least these property values
    :param str patternUrl: Value must have at least these property values
    :param str patternUuid: Value must have at least these property values
    :param Address patternAddress: Value must have at least these property values
    :param Age patternAge: Value must have at least these property values
    :param Annotation patternAnnotation: Value must have at least these property values
    :param Attachment patternAttachment: Value must have at least these property values
    :param CodeableConcept patternCodeableConcept: Value must have at least these property values
    :param CodeableReference patternCodeableReference: Value must have at least these property values
    :param Coding patternCoding: Value must have at least these property values
    :param ContactPoint patternContactPoint: Value must have at least these property values
    :param Count patternCount: Value must have at least these property values
    :param Distance patternDistance: Value must have at least these property values
    :param Duration patternDuration: Value must have at least these property values
    :param HumanName patternHumanName: Value must have at least these property values
    :param Identifier patternIdentifier: Value must have at least these property values
    :param Money patternMoney: Value must have at least these property values
    :param Period patternPeriod: Value must have at least these property values
    :param Quantity patternQuantity: Value must have at least these property values
    :param Range patternRange: Value must have at least these property values
    :param Ratio patternRatio: Value must have at least these property values
    :param RatioRange patternRatioRange: Value must have at least these property values
    :param Reference patternReference: Value must have at least these property values
    :param SampledData patternSampledData: Value must have at least these property values
    :param Signature patternSignature: Value must have at least these property values
    :param Timing patternTiming: Value must have at least these property values
    :param ContactDetail patternContactDetail: Value must have at least these property values
    :param Contributor patternContributor: Value must have at least these property values
    :param DataRequirement patternDataRequirement: Value must have at least these property values
    :param Expression patternExpression: Value must have at least these property values
    :param ParameterDefinition patternParameterDefinition: Value must have at least these property values
    :param RelatedArtifact patternRelatedArtifact: Value must have at least these property values
    :param TriggerDefinition patternTriggerDefinition: Value must have at least these property values
    :param UsageContext patternUsageContext: Value must have at least these property values
    :param Dosage patternDosage: Value must have at least these property values
    :param Example example: Example value (as defined for type)
    :param str minValueDate: Minimum Allowed Value (for some types)
    :param str minValueDateTime: Minimum Allowed Value (for some types)
    :param str minValueInstant: Minimum Allowed Value (for some types)
    :param str minValueTime: Minimum Allowed Value (for some types)
    :param float minValueDecimal: Minimum Allowed Value (for some types)
    :param int minValueInteger: Minimum Allowed Value (for some types)
    :param int minValuePositiveInt: Minimum Allowed Value (for some types)
    :param int minValueUnsignedInt: Minimum Allowed Value (for some types)
    :param Quantity minValueQuantity: Minimum Allowed Value (for some types)
    :param str maxValueDate: Maximum Allowed Value (for some types)
    :param str maxValueDateTime: Maximum Allowed Value (for some types)
    :param str maxValueInstant: Maximum Allowed Value (for some types)
    :param str maxValueTime: Maximum Allowed Value (for some types)
    :param float maxValueDecimal: Maximum Allowed Value (for some types)
    :param int maxValueInteger: Maximum Allowed Value (for some types)
    :param int maxValuePositiveInt: Maximum Allowed Value (for some types)
    :param int maxValueUnsignedInt: Maximum Allowed Value (for some types)
    :param Quantity maxValueQuantity: Maximum Allowed Value (for some types)
    :param int maxLength: Max length for strings
    :param str condition: Reference to invariant about presence
    :param Constraint constraint: Condition that must evaluate to true
    :param bool mustSupport: If the element must be supported
    :param bool isModifier: If this modifies the meaning of other elements
    :param str isModifierReason: Reason that this element is marked as a modifier
    :param bool isSummary: Include when _summary = true?
    :param Binding binding: ValueSet details if this is coded
    :param Mapping mapping: Map element to another set of definitions
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "code": {"class_name": "Coding", "is_contained": False},
        "slicing": {"class_name": "Slicing", "is_contained": True},
        "base": {"class_name": "Base", "is_contained": True},
        "type": {"class_name": "Type", "is_contained": True},
        "defaultValueAddress": {"class_name": "Address", "is_contained": False},
        "defaultValueAge": {"class_name": "Age", "is_contained": False},
        "defaultValueAnnotation": {"class_name": "Annotation", "is_contained": False},
        "defaultValueAttachment": {"class_name": "Attachment", "is_contained": False},
        "defaultValueCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "defaultValueCodeableReference": {
            "class_name": "CodeableReference",
            "is_contained": False,
        },
        "defaultValueCoding": {"class_name": "Coding", "is_contained": False},
        "defaultValueContactPoint": {
            "class_name": "ContactPoint",
            "is_contained": False,
        },
        "defaultValueCount": {"class_name": "Count", "is_contained": False},
        "defaultValueDistance": {"class_name": "Distance", "is_contained": False},
        "defaultValueDuration": {"class_name": "Duration", "is_contained": False},
        "defaultValueHumanName": {"class_name": "HumanName", "is_contained": False},
        "defaultValueIdentifier": {"class_name": "Identifier", "is_contained": False},
        "defaultValueMoney": {"class_name": "Money", "is_contained": False},
        "defaultValuePeriod": {"class_name": "Period", "is_contained": False},
        "defaultValueQuantity": {"class_name": "Quantity", "is_contained": False},
        "defaultValueRange": {"class_name": "Range", "is_contained": False},
        "defaultValueRatio": {"class_name": "Ratio", "is_contained": False},
        "defaultValueRatioRange": {"class_name": "RatioRange", "is_contained": False},
        "defaultValueReference": {"class_name": "Reference", "is_contained": False},
        "defaultValueSampledData": {"class_name": "SampledData", "is_contained": False},
        "defaultValueSignature": {"class_name": "Signature", "is_contained": False},
        "defaultValueTiming": {"class_name": "Timing", "is_contained": False},
        "defaultValueContactDetail": {
            "class_name": "ContactDetail",
            "is_contained": False,
        },
        "defaultValueContributor": {"class_name": "Contributor", "is_contained": False},
        "defaultValueDataRequirement": {
            "class_name": "DataRequirement",
            "is_contained": False,
        },
        "defaultValueExpression": {"class_name": "Expression", "is_contained": False},
        "defaultValueParameterDefinition": {
            "class_name": "ParameterDefinition",
            "is_contained": False,
        },
        "defaultValueRelatedArtifact": {
            "class_name": "RelatedArtifact",
            "is_contained": False,
        },
        "defaultValueTriggerDefinition": {
            "class_name": "TriggerDefinition",
            "is_contained": False,
        },
        "defaultValueUsageContext": {
            "class_name": "UsageContext",
            "is_contained": False,
        },
        "defaultValueDosage": {"class_name": "Dosage", "is_contained": False},
        "fixedAddress": {"class_name": "Address", "is_contained": False},
        "fixedAge": {"class_name": "Age", "is_contained": False},
        "fixedAnnotation": {"class_name": "Annotation", "is_contained": False},
        "fixedAttachment": {"class_name": "Attachment", "is_contained": False},
        "fixedCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "fixedCodeableReference": {
            "class_name": "CodeableReference",
            "is_contained": False,
        },
        "fixedCoding": {"class_name": "Coding", "is_contained": False},
        "fixedContactPoint": {"class_name": "ContactPoint", "is_contained": False},
        "fixedCount": {"class_name": "Count", "is_contained": False},
        "fixedDistance": {"class_name": "Distance", "is_contained": False},
        "fixedDuration": {"class_name": "Duration", "is_contained": False},
        "fixedHumanName": {"class_name": "HumanName", "is_contained": False},
        "fixedIdentifier": {"class_name": "Identifier", "is_contained": False},
        "fixedMoney": {"class_name": "Money", "is_contained": False},
        "fixedPeriod": {"class_name": "Period", "is_contained": False},
        "fixedQuantity": {"class_name": "Quantity", "is_contained": False},
        "fixedRange": {"class_name": "Range", "is_contained": False},
        "fixedRatio": {"class_name": "Ratio", "is_contained": False},
        "fixedRatioRange": {"class_name": "RatioRange", "is_contained": False},
        "fixedReference": {"class_name": "Reference", "is_contained": False},
        "fixedSampledData": {"class_name": "SampledData", "is_contained": False},
        "fixedSignature": {"class_name": "Signature", "is_contained": False},
        "fixedTiming": {"class_name": "Timing", "is_contained": False},
        "fixedContactDetail": {"class_name": "ContactDetail", "is_contained": False},
        "fixedContributor": {"class_name": "Contributor", "is_contained": False},
        "fixedDataRequirement": {
            "class_name": "DataRequirement",
            "is_contained": False,
        },
        "fixedExpression": {"class_name": "Expression", "is_contained": False},
        "fixedParameterDefinition": {
            "class_name": "ParameterDefinition",
            "is_contained": False,
        },
        "fixedRelatedArtifact": {
            "class_name": "RelatedArtifact",
            "is_contained": False,
        },
        "fixedTriggerDefinition": {
            "class_name": "TriggerDefinition",
            "is_contained": False,
        },
        "fixedUsageContext": {"class_name": "UsageContext", "is_contained": False},
        "fixedDosage": {"class_name": "Dosage", "is_contained": False},
        "patternAddress": {"class_name": "Address", "is_contained": False},
        "patternAge": {"class_name": "Age", "is_contained": False},
        "patternAnnotation": {"class_name": "Annotation", "is_contained": False},
        "patternAttachment": {"class_name": "Attachment", "is_contained": False},
        "patternCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "patternCodeableReference": {
            "class_name": "CodeableReference",
            "is_contained": False,
        },
        "patternCoding": {"class_name": "Coding", "is_contained": False},
        "patternContactPoint": {"class_name": "ContactPoint", "is_contained": False},
        "patternCount": {"class_name": "Count", "is_contained": False},
        "patternDistance": {"class_name": "Distance", "is_contained": False},
        "patternDuration": {"class_name": "Duration", "is_contained": False},
        "patternHumanName": {"class_name": "HumanName", "is_contained": False},
        "patternIdentifier": {"class_name": "Identifier", "is_contained": False},
        "patternMoney": {"class_name": "Money", "is_contained": False},
        "patternPeriod": {"class_name": "Period", "is_contained": False},
        "patternQuantity": {"class_name": "Quantity", "is_contained": False},
        "patternRange": {"class_name": "Range", "is_contained": False},
        "patternRatio": {"class_name": "Ratio", "is_contained": False},
        "patternRatioRange": {"class_name": "RatioRange", "is_contained": False},
        "patternReference": {"class_name": "Reference", "is_contained": False},
        "patternSampledData": {"class_name": "SampledData", "is_contained": False},
        "patternSignature": {"class_name": "Signature", "is_contained": False},
        "patternTiming": {"class_name": "Timing", "is_contained": False},
        "patternContactDetail": {"class_name": "ContactDetail", "is_contained": False},
        "patternContributor": {"class_name": "Contributor", "is_contained": False},
        "patternDataRequirement": {
            "class_name": "DataRequirement",
            "is_contained": False,
        },
        "patternExpression": {"class_name": "Expression", "is_contained": False},
        "patternParameterDefinition": {
            "class_name": "ParameterDefinition",
            "is_contained": False,
        },
        "patternRelatedArtifact": {
            "class_name": "RelatedArtifact",
            "is_contained": False,
        },
        "patternTriggerDefinition": {
            "class_name": "TriggerDefinition",
            "is_contained": False,
        },
        "patternUsageContext": {"class_name": "UsageContext", "is_contained": False},
        "patternDosage": {"class_name": "Dosage", "is_contained": False},
        "example": {"class_name": "Example", "is_contained": True},
        "minValueQuantity": {"class_name": "Quantity", "is_contained": False},
        "maxValueQuantity": {"class_name": "Quantity", "is_contained": False},
        "constraint": {"class_name": "Constraint", "is_contained": True},
        "binding": {"class_name": "Binding", "is_contained": True},
        "mapping": {"class_name": "Mapping", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        path: "str" = None,
        representation: list["str"] = None,
        sliceName: "str" = None,
        sliceIsConstraining: "bool" = None,
        label: "str" = None,
        code: list["Coding"] = None,
        slicing: "Slicing" = None,
        short: "str" = None,
        definition: "str" = None,
        comment: "str" = None,
        requirements: "str" = None,
        alias: list["str"] = None,
        min: "int" = None,
        max: "str" = None,
        base: "Base" = None,
        contentReference: "str" = None,
        type: list["Type"] = None,
        defaultValueBase64Binary: "str" = None,
        defaultValueBoolean: "bool" = None,
        defaultValueCanonical: "str" = None,
        defaultValueCode: "str" = None,
        defaultValueDate: "str" = None,
        defaultValueDateTime: "str" = None,
        defaultValueDecimal: "float" = None,
        defaultValueId: "str" = None,
        defaultValueInstant: "str" = None,
        defaultValueInteger: "int" = None,
        defaultValueMarkdown: "str" = None,
        defaultValueOid: "str" = None,
        defaultValuePositiveInt: "int" = None,
        defaultValueString: "str" = None,
        defaultValueTime: "str" = None,
        defaultValueUnsignedInt: "int" = None,
        defaultValueUri: "str" = None,
        defaultValueUrl: "str" = None,
        defaultValueUuid: "str" = None,
        defaultValueAddress: "Address" = None,
        defaultValueAge: "Age" = None,
        defaultValueAnnotation: "Annotation" = None,
        defaultValueAttachment: "Attachment" = None,
        defaultValueCodeableConcept: "CodeableConcept" = None,
        defaultValueCodeableReference: "CodeableReference" = None,
        defaultValueCoding: "Coding" = None,
        defaultValueContactPoint: "ContactPoint" = None,
        defaultValueCount: "Count" = None,
        defaultValueDistance: "Distance" = None,
        defaultValueDuration: "Duration" = None,
        defaultValueHumanName: "HumanName" = None,
        defaultValueIdentifier: "Identifier" = None,
        defaultValueMoney: "Money" = None,
        defaultValuePeriod: "Period" = None,
        defaultValueQuantity: "Quantity" = None,
        defaultValueRange: "Range" = None,
        defaultValueRatio: "Ratio" = None,
        defaultValueRatioRange: "RatioRange" = None,
        defaultValueReference: "Reference" = None,
        defaultValueSampledData: "SampledData" = None,
        defaultValueSignature: "Signature" = None,
        defaultValueTiming: "Timing" = None,
        defaultValueContactDetail: "ContactDetail" = None,
        defaultValueContributor: "Contributor" = None,
        defaultValueDataRequirement: "DataRequirement" = None,
        defaultValueExpression: "Expression" = None,
        defaultValueParameterDefinition: "ParameterDefinition" = None,
        defaultValueRelatedArtifact: "RelatedArtifact" = None,
        defaultValueTriggerDefinition: "TriggerDefinition" = None,
        defaultValueUsageContext: "UsageContext" = None,
        defaultValueDosage: "Dosage" = None,
        meaningWhenMissing: "str" = None,
        orderMeaning: "str" = None,
        fixedBase64Binary: "str" = None,
        fixedBoolean: "bool" = None,
        fixedCanonical: "str" = None,
        fixedCode: "str" = None,
        fixedDate: "str" = None,
        fixedDateTime: "str" = None,
        fixedDecimal: "float" = None,
        fixedId: "str" = None,
        fixedInstant: "str" = None,
        fixedInteger: "int" = None,
        fixedMarkdown: "str" = None,
        fixedOid: "str" = None,
        fixedPositiveInt: "int" = None,
        fixedString: "str" = None,
        fixedTime: "str" = None,
        fixedUnsignedInt: "int" = None,
        fixedUri: "str" = None,
        fixedUrl: "str" = None,
        fixedUuid: "str" = None,
        fixedAddress: "Address" = None,
        fixedAge: "Age" = None,
        fixedAnnotation: "Annotation" = None,
        fixedAttachment: "Attachment" = None,
        fixedCodeableConcept: "CodeableConcept" = None,
        fixedCodeableReference: "CodeableReference" = None,
        fixedCoding: "Coding" = None,
        fixedContactPoint: "ContactPoint" = None,
        fixedCount: "Count" = None,
        fixedDistance: "Distance" = None,
        fixedDuration: "Duration" = None,
        fixedHumanName: "HumanName" = None,
        fixedIdentifier: "Identifier" = None,
        fixedMoney: "Money" = None,
        fixedPeriod: "Period" = None,
        fixedQuantity: "Quantity" = None,
        fixedRange: "Range" = None,
        fixedRatio: "Ratio" = None,
        fixedRatioRange: "RatioRange" = None,
        fixedReference: "Reference" = None,
        fixedSampledData: "SampledData" = None,
        fixedSignature: "Signature" = None,
        fixedTiming: "Timing" = None,
        fixedContactDetail: "ContactDetail" = None,
        fixedContributor: "Contributor" = None,
        fixedDataRequirement: "DataRequirement" = None,
        fixedExpression: "Expression" = None,
        fixedParameterDefinition: "ParameterDefinition" = None,
        fixedRelatedArtifact: "RelatedArtifact" = None,
        fixedTriggerDefinition: "TriggerDefinition" = None,
        fixedUsageContext: "UsageContext" = None,
        fixedDosage: "Dosage" = None,
        patternBase64Binary: "str" = None,
        patternBoolean: "bool" = None,
        patternCanonical: "str" = None,
        patternCode: "str" = None,
        patternDate: "str" = None,
        patternDateTime: "str" = None,
        patternDecimal: "float" = None,
        patternId: "str" = None,
        patternInstant: "str" = None,
        patternInteger: "int" = None,
        patternMarkdown: "str" = None,
        patternOid: "str" = None,
        patternPositiveInt: "int" = None,
        patternString: "str" = None,
        patternTime: "str" = None,
        patternUnsignedInt: "int" = None,
        patternUri: "str" = None,
        patternUrl: "str" = None,
        patternUuid: "str" = None,
        patternAddress: "Address" = None,
        patternAge: "Age" = None,
        patternAnnotation: "Annotation" = None,
        patternAttachment: "Attachment" = None,
        patternCodeableConcept: "CodeableConcept" = None,
        patternCodeableReference: "CodeableReference" = None,
        patternCoding: "Coding" = None,
        patternContactPoint: "ContactPoint" = None,
        patternCount: "Count" = None,
        patternDistance: "Distance" = None,
        patternDuration: "Duration" = None,
        patternHumanName: "HumanName" = None,
        patternIdentifier: "Identifier" = None,
        patternMoney: "Money" = None,
        patternPeriod: "Period" = None,
        patternQuantity: "Quantity" = None,
        patternRange: "Range" = None,
        patternRatio: "Ratio" = None,
        patternRatioRange: "RatioRange" = None,
        patternReference: "Reference" = None,
        patternSampledData: "SampledData" = None,
        patternSignature: "Signature" = None,
        patternTiming: "Timing" = None,
        patternContactDetail: "ContactDetail" = None,
        patternContributor: "Contributor" = None,
        patternDataRequirement: "DataRequirement" = None,
        patternExpression: "Expression" = None,
        patternParameterDefinition: "ParameterDefinition" = None,
        patternRelatedArtifact: "RelatedArtifact" = None,
        patternTriggerDefinition: "TriggerDefinition" = None,
        patternUsageContext: "UsageContext" = None,
        patternDosage: "Dosage" = None,
        example: list["Example"] = None,
        minValueDate: "str" = None,
        minValueDateTime: "str" = None,
        minValueInstant: "str" = None,
        minValueTime: "str" = None,
        minValueDecimal: "float" = None,
        minValueInteger: "int" = None,
        minValuePositiveInt: "int" = None,
        minValueUnsignedInt: "int" = None,
        minValueQuantity: "Quantity" = None,
        maxValueDate: "str" = None,
        maxValueDateTime: "str" = None,
        maxValueInstant: "str" = None,
        maxValueTime: "str" = None,
        maxValueDecimal: "float" = None,
        maxValueInteger: "int" = None,
        maxValuePositiveInt: "int" = None,
        maxValueUnsignedInt: "int" = None,
        maxValueQuantity: "Quantity" = None,
        maxLength: "int" = None,
        condition: list["str"] = None,
        constraint: list["Constraint"] = None,
        mustSupport: "bool" = None,
        isModifier: "bool" = None,
        isModifierReason: "str" = None,
        isSummary: "bool" = None,
        binding: "Binding" = None,
        mapping: list["Mapping"] = None,
    ):

        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.path = path
        self.representation = representation or []
        self.sliceName = sliceName
        self.sliceIsConstraining = sliceIsConstraining
        self.label = label
        self.code = code or []
        self.slicing = slicing
        self.short = short
        self.definition = definition
        self.comment = comment
        self.requirements = requirements
        self.alias = alias or []
        self.min = min
        self.max = max
        self.base = base
        self.contentReference = contentReference
        self.type = type or []
        self.defaultValueBase64Binary = defaultValueBase64Binary
        self.defaultValueBoolean = defaultValueBoolean
        self.defaultValueCanonical = defaultValueCanonical
        self.defaultValueCode = defaultValueCode
        self.defaultValueDate = defaultValueDate
        self.defaultValueDateTime = defaultValueDateTime
        self.defaultValueDecimal = defaultValueDecimal
        self.defaultValueId = defaultValueId
        self.defaultValueInstant = defaultValueInstant
        self.defaultValueInteger = defaultValueInteger
        self.defaultValueMarkdown = defaultValueMarkdown
        self.defaultValueOid = defaultValueOid
        self.defaultValuePositiveInt = defaultValuePositiveInt
        self.defaultValueString = defaultValueString
        self.defaultValueTime = defaultValueTime
        self.defaultValueUnsignedInt = defaultValueUnsignedInt
        self.defaultValueUri = defaultValueUri
        self.defaultValueUrl = defaultValueUrl
        self.defaultValueUuid = defaultValueUuid
        self.defaultValueAddress = defaultValueAddress
        self.defaultValueAge = defaultValueAge
        self.defaultValueAnnotation = defaultValueAnnotation
        self.defaultValueAttachment = defaultValueAttachment
        self.defaultValueCodeableConcept = defaultValueCodeableConcept
        self.defaultValueCodeableReference = defaultValueCodeableReference
        self.defaultValueCoding = defaultValueCoding
        self.defaultValueContactPoint = defaultValueContactPoint
        self.defaultValueCount = defaultValueCount
        self.defaultValueDistance = defaultValueDistance
        self.defaultValueDuration = defaultValueDuration
        self.defaultValueHumanName = defaultValueHumanName
        self.defaultValueIdentifier = defaultValueIdentifier
        self.defaultValueMoney = defaultValueMoney
        self.defaultValuePeriod = defaultValuePeriod
        self.defaultValueQuantity = defaultValueQuantity
        self.defaultValueRange = defaultValueRange
        self.defaultValueRatio = defaultValueRatio
        self.defaultValueRatioRange = defaultValueRatioRange
        self.defaultValueReference = defaultValueReference
        self.defaultValueSampledData = defaultValueSampledData
        self.defaultValueSignature = defaultValueSignature
        self.defaultValueTiming = defaultValueTiming
        self.defaultValueContactDetail = defaultValueContactDetail
        self.defaultValueContributor = defaultValueContributor
        self.defaultValueDataRequirement = defaultValueDataRequirement
        self.defaultValueExpression = defaultValueExpression
        self.defaultValueParameterDefinition = defaultValueParameterDefinition
        self.defaultValueRelatedArtifact = defaultValueRelatedArtifact
        self.defaultValueTriggerDefinition = defaultValueTriggerDefinition
        self.defaultValueUsageContext = defaultValueUsageContext
        self.defaultValueDosage = defaultValueDosage
        self.meaningWhenMissing = meaningWhenMissing
        self.orderMeaning = orderMeaning
        self.fixedBase64Binary = fixedBase64Binary
        self.fixedBoolean = fixedBoolean
        self.fixedCanonical = fixedCanonical
        self.fixedCode = fixedCode
        self.fixedDate = fixedDate
        self.fixedDateTime = fixedDateTime
        self.fixedDecimal = fixedDecimal
        self.fixedId = fixedId
        self.fixedInstant = fixedInstant
        self.fixedInteger = fixedInteger
        self.fixedMarkdown = fixedMarkdown
        self.fixedOid = fixedOid
        self.fixedPositiveInt = fixedPositiveInt
        self.fixedString = fixedString
        self.fixedTime = fixedTime
        self.fixedUnsignedInt = fixedUnsignedInt
        self.fixedUri = fixedUri
        self.fixedUrl = fixedUrl
        self.fixedUuid = fixedUuid
        self.fixedAddress = fixedAddress
        self.fixedAge = fixedAge
        self.fixedAnnotation = fixedAnnotation
        self.fixedAttachment = fixedAttachment
        self.fixedCodeableConcept = fixedCodeableConcept
        self.fixedCodeableReference = fixedCodeableReference
        self.fixedCoding = fixedCoding
        self.fixedContactPoint = fixedContactPoint
        self.fixedCount = fixedCount
        self.fixedDistance = fixedDistance
        self.fixedDuration = fixedDuration
        self.fixedHumanName = fixedHumanName
        self.fixedIdentifier = fixedIdentifier
        self.fixedMoney = fixedMoney
        self.fixedPeriod = fixedPeriod
        self.fixedQuantity = fixedQuantity
        self.fixedRange = fixedRange
        self.fixedRatio = fixedRatio
        self.fixedRatioRange = fixedRatioRange
        self.fixedReference = fixedReference
        self.fixedSampledData = fixedSampledData
        self.fixedSignature = fixedSignature
        self.fixedTiming = fixedTiming
        self.fixedContactDetail = fixedContactDetail
        self.fixedContributor = fixedContributor
        self.fixedDataRequirement = fixedDataRequirement
        self.fixedExpression = fixedExpression
        self.fixedParameterDefinition = fixedParameterDefinition
        self.fixedRelatedArtifact = fixedRelatedArtifact
        self.fixedTriggerDefinition = fixedTriggerDefinition
        self.fixedUsageContext = fixedUsageContext
        self.fixedDosage = fixedDosage
        self.patternBase64Binary = patternBase64Binary
        self.patternBoolean = patternBoolean
        self.patternCanonical = patternCanonical
        self.patternCode = patternCode
        self.patternDate = patternDate
        self.patternDateTime = patternDateTime
        self.patternDecimal = patternDecimal
        self.patternId = patternId
        self.patternInstant = patternInstant
        self.patternInteger = patternInteger
        self.patternMarkdown = patternMarkdown
        self.patternOid = patternOid
        self.patternPositiveInt = patternPositiveInt
        self.patternString = patternString
        self.patternTime = patternTime
        self.patternUnsignedInt = patternUnsignedInt
        self.patternUri = patternUri
        self.patternUrl = patternUrl
        self.patternUuid = patternUuid
        self.patternAddress = patternAddress
        self.patternAge = patternAge
        self.patternAnnotation = patternAnnotation
        self.patternAttachment = patternAttachment
        self.patternCodeableConcept = patternCodeableConcept
        self.patternCodeableReference = patternCodeableReference
        self.patternCoding = patternCoding
        self.patternContactPoint = patternContactPoint
        self.patternCount = patternCount
        self.patternDistance = patternDistance
        self.patternDuration = patternDuration
        self.patternHumanName = patternHumanName
        self.patternIdentifier = patternIdentifier
        self.patternMoney = patternMoney
        self.patternPeriod = patternPeriod
        self.patternQuantity = patternQuantity
        self.patternRange = patternRange
        self.patternRatio = patternRatio
        self.patternRatioRange = patternRatioRange
        self.patternReference = patternReference
        self.patternSampledData = patternSampledData
        self.patternSignature = patternSignature
        self.patternTiming = patternTiming
        self.patternContactDetail = patternContactDetail
        self.patternContributor = patternContributor
        self.patternDataRequirement = patternDataRequirement
        self.patternExpression = patternExpression
        self.patternParameterDefinition = patternParameterDefinition
        self.patternRelatedArtifact = patternRelatedArtifact
        self.patternTriggerDefinition = patternTriggerDefinition
        self.patternUsageContext = patternUsageContext
        self.patternDosage = patternDosage
        self.example = example or []
        self.minValueDate = minValueDate
        self.minValueDateTime = minValueDateTime
        self.minValueInstant = minValueInstant
        self.minValueTime = minValueTime
        self.minValueDecimal = minValueDecimal
        self.minValueInteger = minValueInteger
        self.minValuePositiveInt = minValuePositiveInt
        self.minValueUnsignedInt = minValueUnsignedInt
        self.minValueQuantity = minValueQuantity
        self.maxValueDate = maxValueDate
        self.maxValueDateTime = maxValueDateTime
        self.maxValueInstant = maxValueInstant
        self.maxValueTime = maxValueTime
        self.maxValueDecimal = maxValueDecimal
        self.maxValueInteger = maxValueInteger
        self.maxValuePositiveInt = maxValuePositiveInt
        self.maxValueUnsignedInt = maxValueUnsignedInt
        self.maxValueQuantity = maxValueQuantity
        self.maxLength = maxLength
        self.condition = condition or []
        self.constraint = constraint or []
        self.mustSupport = mustSupport
        self.isModifier = isModifier
        self.isModifierReason = isModifierReason
        self.isSummary = isSummary
        self.binding = binding
        self.mapping = mapping or []

    @classmethod
    def from_dict(cls, data: dict) -> "ElementDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ElementDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Specimen. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.R4B.Annotation import *
from fhirmodels.R4B.BackboneElement import *
from fhirmodels.R4B.CodeableConcept import *
from fhirmodels.R4B.DomainResource import *
from fhirmodels.R4B.Duration import *
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.Identifier import *
from fhirmodels.R4B.Meta import *
from fhirmodels.R4B.Narrative import *
from fhirmodels.R4B.Period import *
from fhirmodels.R4B.Quantity import *
from fhirmodels.R4B.Reference import *
from fhirmodels.R4B.Resource import *


class Collection(FhirBaseModel):
    """Details concerning the specimen collection.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Reference collector: Who collected the specimen
    :param str collectedDateTime: Collection time
    :param Period collectedPeriod: Collection time
    :param Duration duration: How long it took to collect specimen
    :param Quantity quantity: The quantity of specimen collected
    :param CodeableConcept method: Technique used to perform collection
    :param CodeableConcept bodySite: Anatomical collection site
    :param CodeableConcept fastingStatusCodeableConcept: Whether or how long patient abstained from food and/or drink
    :param Duration fastingStatusDuration: Whether or how long patient abstained from food and/or drink
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "collector": {"class_name": "Reference", "is_contained": False},
        "collectedPeriod": {"class_name": "Period", "is_contained": False},
        "duration": {"class_name": "Duration", "is_contained": False},
        "quantity": {"class_name": "Quantity", "is_contained": False},
        "method": {"class_name": "CodeableConcept", "is_contained": False},
        "bodySite": {"class_name": "CodeableConcept", "is_contained": False},
        "fastingStatusCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "fastingStatusDuration": {"class_name": "Duration", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        collector: "Reference" = None,
        collectedDateTime: "str" = None,
        collectedPeriod: "Period" = None,
        duration: "Duration" = None,
        quantity: "Quantity" = None,
        method: "CodeableConcept" = None,
        bodySite: "CodeableConcept" = None,
        fastingStatusCodeableConcept: "CodeableConcept" = None,
        fastingStatusDuration: "Duration" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.collector = collector
        self.collectedDateTime = collectedDateTime
        self.collectedPeriod = collectedPeriod
        self.duration = duration
        self.quantity = quantity
        self.method = method
        self.bodySite = bodySite
        self.fastingStatusCodeableConcept = fastingStatusCodeableConcept
        self.fastingStatusDuration = fastingStatusDuration

    @classmethod
    def from_dict(cls, data: dict) -> "Specimen":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Specimen":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Processing(FhirBaseModel):
    """Details concerning processing and processing steps for the specimen.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str description: Textual description of procedure
    :param CodeableConcept procedure: Indicates the treatment step  applied to the specimen
    :param Reference additive: Material used in the processing step
    :param str timeDateTime: Date and time of specimen processing
    :param Period timePeriod: Date and time of specimen processing
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "procedure": {"class_name": "CodeableConcept", "is_contained": False},
        "additive": {"class_name": "Reference", "is_contained": False},
        "timePeriod": {"class_name": "Period", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        description: "str" = None,
        procedure: "CodeableConcept" = None,
        additive: list["Reference"] = None,
        timeDateTime: "str" = None,
        timePeriod: "Period" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.description = description
        self.procedure = procedure
        self.additive = additive or []
        self.timeDateTime = timeDateTime
        self.timePeriod = timePeriod

    @classmethod
    def from_dict(cls, data: dict) -> "Specimen":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Specimen":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Container(FhirBaseModel):
    """The container holding the specimen.  The recursive nature of containers; i.e. blood in tube in tray in rack is not addressed here.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Identifier identifier: Id for the container
    :param str description: Textual description of the container
    :param CodeableConcept type: Kind of container directly associated with specimen
    :param Quantity capacity: Container volume or size
    :param Quantity specimenQuantity: Quantity of specimen within container
    :param CodeableConcept additiveCodeableConcept: Additive associated with container
    :param Reference additiveReference: Additive associated with container
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "capacity": {"class_name": "Quantity", "is_contained": False},
        "specimenQuantity": {"class_name": "Quantity", "is_contained": False},
        "additiveCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "additiveReference": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        description: "str" = None,
        type: "CodeableConcept" = None,
        capacity: "Quantity" = None,
        specimenQuantity: "Quantity" = None,
        additiveCodeableConcept: "CodeableConcept" = None,
        additiveReference: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.description = description
        self.type = type
        self.capacity = capacity
        self.specimenQuantity = specimenQuantity
        self.additiveCodeableConcept = additiveCodeableConcept
        self.additiveReference = additiveReference

    @classmethod
    def from_dict(cls, data: dict) -> "Specimen":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Specimen":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Specimen(DomainResource):
    """A sample to be used for analysis.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: External Identifier
    :param Identifier accessionIdentifier: Identifier assigned by the lab
    :param str status: available | unavailable | unsatisfactory | entered-in-error
    :param CodeableConcept type: Kind of material that forms the specimen
    :param Reference subject: Where the specimen came from. This may be from patient(s), from a location (e.g., the source of an environmental sample), or a sampling of a substance or a device
    :param str receivedTime: The time when specimen was received for processing
    :param Reference parent: Specimen from which this specimen originated
    :param Reference request: Why the specimen was collected
    :param Collection collection: Collection details
    :param Processing processing: Processing and processing step details
    :param Container container: Direct container of specimen (tube/slide, etc.)
    :param CodeableConcept condition: State of the specimen
    :param Annotation note: Comments
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "accessionIdentifier": {"class_name": "Identifier", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "parent": {"class_name": "Reference", "is_contained": False},
        "request": {"class_name": "Reference", "is_contained": False},
        "collection": {"class_name": "Collection", "is_contained": True},
        "processing": {"class_name": "Processing", "is_contained": True},
        "container": {"class_name": "Container", "is_contained": True},
        "condition": {"class_name": "CodeableConcept", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        accessionIdentifier: "Identifier" = None,
        status: "str" = None,
        type: "CodeableConcept" = None,
        subject: "Reference" = None,
        receivedTime: "str" = None,
        parent: list["Reference"] = None,
        request: list["Reference"] = None,
        collection: "Collection" = None,
        processing: list["Processing"] = None,
        container: list["Container"] = None,
        condition: list["CodeableConcept"] = None,
        note: list["Annotation"] = None,
    ):

        self.resourceType = "Specimen"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.accessionIdentifier = accessionIdentifier
        self.status = status
        self.type = type
        self.subject = subject
        self.receivedTime = receivedTime
        self.parent = parent or []
        self.request = request or []
        self.collection = collection
        self.processing = processing or []
        self.container = container or []
        self.condition = condition or []
        self.note = note or []

    @classmethod
    def from_dict(cls, data: dict) -> "Specimen":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Specimen":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for ChargeItemDefinition. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.Coding import *
from fhirmodels.R5.ContactDetail import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Expression import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.MonetaryComponent import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Period import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.RelatedArtifact import *
from fhirmodels.R5.Resource import *
from fhirmodels.R5.UsageContext import *


class Applicability(FhirBaseModel):
    """Expressions that describe applicability criteria for the billing code.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Expression condition: Boolean-valued expression
    :param Period effectivePeriod: When the charge item definition is expected to be used
    :param RelatedArtifact relatedArtifact: Reference to / quotation of the external source of the group of properties
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "condition": {"class_name": "Expression", "is_contained": False},
        "effectivePeriod": {"class_name": "Period", "is_contained": False},
        "relatedArtifact": {"class_name": "RelatedArtifact", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        condition: "Expression" = None,
        effectivePeriod: "Period" = None,
        relatedArtifact: "RelatedArtifact" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.condition = condition
        self.effectivePeriod = effectivePeriod
        self.relatedArtifact = relatedArtifact

    @classmethod
    def from_dict(cls, data: dict) -> "ChargeItemDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ChargeItemDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class PropertyGroup(FhirBaseModel):
    """Group of properties which are applicable under the same conditions. If no applicability rules are established for the group, then all properties always apply.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Applicability applicability: Conditions under which the priceComponent is applicable
    :param MonetaryComponent priceComponent: Components of total line item price
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "applicability": {"class_name": "Applicability", "is_contained": True},
        "priceComponent": {"class_name": "MonetaryComponent", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        applicability: list["Applicability"] = None,
        priceComponent: list["MonetaryComponent"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.applicability = applicability or []
        self.priceComponent = priceComponent or []

    @classmethod
    def from_dict(cls, data: dict) -> "ChargeItemDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ChargeItemDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ChargeItemDefinition(DomainResource):
    """The ChargeItemDefinition resource provides the properties that apply to the (billing) codes necessary to calculate costs and prices. The properties may differ largely depending on type and realm, therefore this resource gives only a rough structure and requires profiling for each type of billing code system.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param str url: Canonical identifier for this charge item definition, represented as a URI (globally unique)
    :param Identifier identifier: Additional identifier for the charge item definition
    :param str version: Business version of the charge item definition
    :param str versionAlgorithmString: How to compare versions
    :param Coding versionAlgorithmCoding: How to compare versions
    :param str name: Name for this charge item definition (computer friendly)
    :param str title: Name for this charge item definition (human friendly)
    :param str derivedFromUri: Underlying externally-defined charge item definition
    :param str partOf: A larger definition of which this particular definition is a component or step
    :param str replaces: Completed or terminated request(s) whose function is taken by this new request
    :param str status: draft | active | retired | unknown
    :param bool experimental: For testing purposes, not real usage
    :param str date: Date last changed
    :param str publisher: Name of the publisher/steward (organization or individual)
    :param ContactDetail contact: Contact details for the publisher
    :param str description: Natural language description of the charge item definition
    :param UsageContext useContext: The context that the content is intended to support
    :param CodeableConcept jurisdiction: Intended jurisdiction for charge item definition (if applicable)
    :param str purpose: Why this charge item definition is defined
    :param str copyright: Use and/or publishing restrictions
    :param str copyrightLabel: Copyright holder and year(s)
    :param str approvalDate: When the charge item definition was approved by publisher
    :param str lastReviewDate: When the charge item definition was last reviewed by the publisher
    :param CodeableConcept code: Billing code or product type this definition applies to
    :param Reference instance: Instances this definition applies to
    :param Applicability applicability: Whether or not the billing code is applicable
    :param PropertyGroup propertyGroup: Group of properties which are applicable under the same conditions
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "versionAlgorithmCoding": {"class_name": "Coding", "is_contained": False},
        "contact": {"class_name": "ContactDetail", "is_contained": False},
        "useContext": {"class_name": "UsageContext", "is_contained": False},
        "jurisdiction": {"class_name": "CodeableConcept", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "instance": {"class_name": "Reference", "is_contained": False},
        "applicability": {"class_name": "Applicability", "is_contained": True},
        "propertyGroup": {"class_name": "PropertyGroup", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        url: "str" = None,
        identifier: list["Identifier"] = None,
        version: "str" = None,
        versionAlgorithmString: "str" = None,
        versionAlgorithmCoding: "Coding" = None,
        name: "str" = None,
        title: "str" = None,
        derivedFromUri: list["str"] = None,
        partOf: list["str"] = None,
        replaces: list["str"] = None,
        status: "str" = None,
        experimental: "bool" = None,
        date: "str" = None,
        publisher: "str" = None,
        contact: list["ContactDetail"] = None,
        description: "str" = None,
        useContext: list["UsageContext"] = None,
        jurisdiction: list["CodeableConcept"] = None,
        purpose: "str" = None,
        copyright: "str" = None,
        copyrightLabel: "str" = None,
        approvalDate: "str" = None,
        lastReviewDate: "str" = None,
        code: "CodeableConcept" = None,
        instance: list["Reference"] = None,
        applicability: list["Applicability"] = None,
        propertyGroup: list["PropertyGroup"] = None,
    ):

        self.resourceType = "ChargeItemDefinition"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.url = url
        self.identifier = identifier or []
        self.version = version
        self.versionAlgorithmString = versionAlgorithmString
        self.versionAlgorithmCoding = versionAlgorithmCoding
        self.name = name
        self.title = title
        self.derivedFromUri = derivedFromUri or []
        self.partOf = partOf or []
        self.replaces = replaces or []
        self.status = status
        self.experimental = experimental
        self.date = date
        self.publisher = publisher
        self.contact = contact or []
        self.description = description
        self.useContext = useContext or []
        self.jurisdiction = jurisdiction or []
        self.purpose = purpose
        self.copyright = copyright
        self.copyrightLabel = copyrightLabel
        self.approvalDate = approvalDate
        self.lastReviewDate = lastReviewDate
        self.code = code
        self.instance = instance or []
        self.applicability = applicability or []
        self.propertyGroup = propertyGroup or []

    @classmethod
    def from_dict(cls, data: dict) -> "ChargeItemDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ChargeItemDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for BiologicallyDerivedProduct. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.R4.BackboneElement import *
from fhirmodels.R4.CodeableConcept import *
from fhirmodels.R4.DomainResource import *
from fhirmodels.R4.Extension import *
from fhirmodels.R4.Identifier import *
from fhirmodels.R4.Meta import *
from fhirmodels.R4.Narrative import *
from fhirmodels.R4.Period import *
from fhirmodels.R4.Reference import *
from fhirmodels.R4.Resource import *


class Collection(FhirBaseModel):
    """How this product was collected.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Reference collector: Individual performing collection
    :param Reference source: Who is product from
    :param str collectedDateTime: Time of product collection
    :param Period collectedPeriod: Time of product collection
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "collector": {"class_name": "Reference", "is_contained": False},
        "source": {"class_name": "Reference", "is_contained": False},
        "collectedPeriod": {"class_name": "Period", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        collector: "Reference" = None,
        source: "Reference" = None,
        collectedDateTime: "str" = None,
        collectedPeriod: "Period" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.collector = collector
        self.source = source
        self.collectedDateTime = collectedDateTime
        self.collectedPeriod = collectedPeriod

    @classmethod
    def from_dict(cls, data: dict) -> "BiologicallyDerivedProduct":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "BiologicallyDerivedProduct":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Processing(FhirBaseModel):
    """Any processing of the product during collection that does not change the fundamental nature of the product. For example adding anti-coagulants during the collection of Peripheral Blood Stem Cells.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str description: Description of of processing
    :param CodeableConcept procedure: Procesing code
    :param Reference additive: Substance added during processing
    :param str timeDateTime: Time of processing
    :param Period timePeriod: Time of processing
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "procedure": {"class_name": "CodeableConcept", "is_contained": False},
        "additive": {"class_name": "Reference", "is_contained": False},
        "timePeriod": {"class_name": "Period", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        description: "str" = None,
        procedure: "CodeableConcept" = None,
        additive: "Reference" = None,
        timeDateTime: "str" = None,
        timePeriod: "Period" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.description = description
        self.procedure = procedure
        self.additive = additive
        self.timeDateTime = timeDateTime
        self.timePeriod = timePeriod

    @classmethod
    def from_dict(cls, data: dict) -> "BiologicallyDerivedProduct":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "BiologicallyDerivedProduct":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Manipulation(FhirBaseModel):
    """Any manipulation of product post-collection that is intended to alter the product.  For example a buffy-coat enrichment or CD8 reduction of Peripheral Blood Stem Cells to make it more suitable for infusion.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str description: Description of manipulation
    :param str timeDateTime: Time of manipulation
    :param Period timePeriod: Time of manipulation
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "timePeriod": {"class_name": "Period", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        description: "str" = None,
        timeDateTime: "str" = None,
        timePeriod: "Period" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.description = description
        self.timeDateTime = timeDateTime
        self.timePeriod = timePeriod

    @classmethod
    def from_dict(cls, data: dict) -> "BiologicallyDerivedProduct":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "BiologicallyDerivedProduct":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Storage(FhirBaseModel):
    """Product storage.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str description: Description of storage
    :param float temperature: Storage temperature
    :param str scale: farenheit | celsius | kelvin
    :param Period duration: Storage timeperiod
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "duration": {"class_name": "Period", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        description: "str" = None,
        temperature: "float" = None,
        scale: "str" = None,
        duration: "Period" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.description = description
        self.temperature = temperature
        self.scale = scale
        self.duration = duration

    @classmethod
    def from_dict(cls, data: dict) -> "BiologicallyDerivedProduct":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "BiologicallyDerivedProduct":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class BiologicallyDerivedProduct(DomainResource):
    """A material substance originating from a biological entity intended to be transplanted or infused
    into another (possibly the same) biological entity.
        :param str id: Logical id of this artifact
        :param Meta meta: Metadata about the resource
        :param str implicitRules: A set of rules under which this content was created
        :param str language: Language of the resource content
        :param Narrative text: Text summary of the resource, for human interpretation
        :param Resource contained: Contained, inline Resources
        :param Extension extension: Additional content defined by implementations
        :param Extension modifierExtension: Extensions that cannot be ignored
        :param Identifier identifier: External ids for this item
        :param str productCategory: organ | tissue | fluid | cells | biologicalAgent
        :param CodeableConcept productCode: What this biologically derived product is
        :param str status: available | unavailable
        :param Reference request: Procedure request
        :param int quantity: The amount of this biologically derived product
        :param Reference parent: BiologicallyDerivedProduct parent
        :param Collection collection: How this product was collected
        :param Processing processing: Any processing of the product during collection
        :param Manipulation manipulation: Any manipulation of product post-collection
        :param Storage storage: Product storage
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "productCode": {"class_name": "CodeableConcept", "is_contained": False},
        "request": {"class_name": "Reference", "is_contained": False},
        "parent": {"class_name": "Reference", "is_contained": False},
        "collection": {"class_name": "Collection", "is_contained": True},
        "processing": {"class_name": "Processing", "is_contained": True},
        "manipulation": {"class_name": "Manipulation", "is_contained": True},
        "storage": {"class_name": "Storage", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        productCategory: "str" = None,
        productCode: "CodeableConcept" = None,
        status: "str" = None,
        request: list["Reference"] = None,
        quantity: "int" = None,
        parent: list["Reference"] = None,
        collection: "Collection" = None,
        processing: list["Processing"] = None,
        manipulation: "Manipulation" = None,
        storage: list["Storage"] = None,
    ):

        self.resourceType = "BiologicallyDerivedProduct"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.productCategory = productCategory
        self.productCode = productCode
        self.status = status
        self.request = request or []
        self.quantity = quantity
        self.parent = parent or []
        self.collection = collection
        self.processing = processing or []
        self.manipulation = manipulation
        self.storage = storage or []

    @classmethod
    def from_dict(cls, data: dict) -> "BiologicallyDerivedProduct":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "BiologicallyDerivedProduct":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for MedicinalProductManufactured. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.R4.CodeableConcept import *
from fhirmodels.R4.DomainResource import *
from fhirmodels.R4.Extension import *
from fhirmodels.R4.Meta import *
from fhirmodels.R4.Narrative import *
from fhirmodels.R4.ProdCharacteristic import *
from fhirmodels.R4.Quantity import *
from fhirmodels.R4.Reference import *
from fhirmodels.R4.Resource import *


class MedicinalProductManufactured(DomainResource):
    """The manufactured item as contained in the packaged medicinal product.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param CodeableConcept manufacturedDoseForm: Dose form as manufactured and before any transformation into the pharmaceutical product
    :param CodeableConcept unitOfPresentation: The “real world” units in which the quantity of the manufactured item is described
    :param Quantity quantity: The quantity or "count number" of the manufactured item
    :param Reference manufacturer: Manufacturer of the item (Note that this should be named "manufacturer" but it currently causes technical issues)
    :param Reference ingredient: Ingredient
    :param ProdCharacteristic physicalCharacteristics: Dimensions, color etc.
    :param CodeableConcept otherCharacteristics: Other codeable characteristics
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "manufacturedDoseForm": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "unitOfPresentation": {"class_name": "CodeableConcept", "is_contained": False},
        "quantity": {"class_name": "Quantity", "is_contained": False},
        "manufacturer": {"class_name": "Reference", "is_contained": False},
        "ingredient": {"class_name": "Reference", "is_contained": False},
        "physicalCharacteristics": {
            "class_name": "ProdCharacteristic",
            "is_contained": False,
        },
        "otherCharacteristics": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        manufacturedDoseForm: "CodeableConcept" = None,
        unitOfPresentation: "CodeableConcept" = None,
        quantity: "Quantity" = None,
        manufacturer: list["Reference"] = None,
        ingredient: list["Reference"] = None,
        physicalCharacteristics: "ProdCharacteristic" = None,
        otherCharacteristics: list["CodeableConcept"] = None,
    ):

        self.resourceType = "MedicinalProductManufactured"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.manufacturedDoseForm = manufacturedDoseForm
        self.unitOfPresentation = unitOfPresentation
        self.quantity = quantity
        self.manufacturer = manufacturer or []
        self.ingredient = ingredient or []
        self.physicalCharacteristics = physicalCharacteristics
        self.otherCharacteristics = otherCharacteristics or []

    @classmethod
    def from_dict(cls, data: dict) -> "MedicinalProductManufactured":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicinalProductManufactured":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Evidence. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.R4.Annotation import *
from fhirmodels.R4.CodeableConcept import *
from fhirmodels.R4.ContactDetail import *
from fhirmodels.R4.DomainResource import *
from fhirmodels.R4.Extension import *
from fhirmodels.R4.Identifier import *
from fhirmodels.R4.Meta import *
from fhirmodels.R4.Narrative import *
from fhirmodels.R4.Period import *
from fhirmodels.R4.Reference import *
from fhirmodels.R4.RelatedArtifact import *
from fhirmodels.R4.Resource import *
from fhirmodels.R4.UsageContext import *


class Evidence(DomainResource):
    """The Evidence resource describes the conditional state (population and any exposures being compared within the population) and outcome (if specified) that the knowledge (evidence, assertion, recommendation) is about.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param str url: Canonical identifier for this evidence, represented as a URI (globally unique)
    :param Identifier identifier: Additional identifier for the evidence
    :param str version: Business version of the evidence
    :param str name: Name for this evidence (computer friendly)
    :param str title: Name for this evidence (human friendly)
    :param str shortTitle: Title for use in informal contexts
    :param str subtitle: Subordinate title of the Evidence
    :param str status: draft | active | retired | unknown
    :param str date: Date last changed
    :param str publisher: Name of the publisher (organization or individual)
    :param ContactDetail contact: Contact details for the publisher
    :param str description: Natural language description of the evidence
    :param Annotation note: Used for footnotes or explanatory notes
    :param UsageContext useContext: The context that the content is intended to support
    :param CodeableConcept jurisdiction: Intended jurisdiction for evidence (if applicable)
    :param str copyright: Use and/or publishing restrictions
    :param str approvalDate: When the evidence was approved by publisher
    :param str lastReviewDate: When the evidence was last reviewed
    :param Period effectivePeriod: When the evidence is expected to be used
    :param CodeableConcept topic: The category of the Evidence, such as Education, Treatment, Assessment, etc.
    :param ContactDetail author: Who authored the content
    :param ContactDetail editor: Who edited the content
    :param ContactDetail reviewer: Who reviewed the content
    :param ContactDetail endorser: Who endorsed the content
    :param RelatedArtifact relatedArtifact: Additional documentation, citations, etc.
    :param Reference exposureBackground: What population?
    :param Reference exposureVariant: What exposure?
    :param Reference outcome: What outcome?
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "contact": {"class_name": "ContactDetail", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
        "useContext": {"class_name": "UsageContext", "is_contained": False},
        "jurisdiction": {"class_name": "CodeableConcept", "is_contained": False},
        "effectivePeriod": {"class_name": "Period", "is_contained": False},
        "topic": {"class_name": "CodeableConcept", "is_contained": False},
        "author": {"class_name": "ContactDetail", "is_contained": False},
        "editor": {"class_name": "ContactDetail", "is_contained": False},
        "reviewer": {"class_name": "ContactDetail", "is_contained": False},
        "endorser": {"class_name": "ContactDetail", "is_contained": False},
        "relatedArtifact": {"class_name": "RelatedArtifact", "is_contained": False},
        "exposureBackground": {"class_name": "Reference", "is_contained": False},
        "exposureVariant": {"class_name": "Reference", "is_contained": False},
        "outcome": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        url: "str" = None,
        identifier: list["Identifier"] = None,
        version: "str" = None,
        name: "str" = None,
        title: "str" = None,
        shortTitle: "str" = None,
        subtitle: "str" = None,
        status: "str" = None,
        date: "str" = None,
        publisher: "str" = None,
        contact: list["ContactDetail"] = None,
        description: "str" = None,
        note: list["Annotation"] = None,
        useContext: list["UsageContext"] = None,
        jurisdiction: list["CodeableConcept"] = None,
        copyright: "str" = None,
        approvalDate: "str" = None,
        lastReviewDate: "str" = None,
        effectivePeriod: "Period" = None,
        topic: list["CodeableConcept"] = None,
        author: list["ContactDetail"] = None,
        editor: list["ContactDetail"] = None,
        reviewer: list["ContactDetail"] = None,
        endorser: list["ContactDetail"] = None,
        relatedArtifact: list["RelatedArtifact"] = None,
        exposureBackground: "Reference" = None,
        exposureVariant: list["Reference"] = None,
        outcome: list["Reference"] = None,
    ):

        self.resourceType = "Evidence"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.url = url
        self.identifier = identifier or []
        self.version = version
        self.name = name
        self.title = title
        self.shortTitle = shortTitle
        self.subtitle = subtitle
        self.status = status
        self.date = date
        self.publisher = publisher
        self.contact = contact or []
        self.description = description
        self.note = note or []
        self.useContext = useContext or []
        self.jurisdiction = jurisdiction or []
        self.copyright = copyright
        self.approvalDate = approvalDate
        self.lastReviewDate = lastReviewDate
        self.effectivePeriod = effectivePeriod
        self.topic = topic or []
        self.author = author or []
        self.editor = editor or []
        self.reviewer = reviewer or []
        self.endorser = endorser or []
        self.relatedArtifact = relatedArtifact or []
        self.exposureBackground = exposureBackground
        self.exposureVariant = exposureVariant or []
        self.outcome = outcome or []

    @classmethod
    def from_dict(cls, data: dict) -> "Evidence":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Evidence":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for DeviceUsage. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.Annotation import *
from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.CodeableReference import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Period import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Resource import *
from fhirmodels.R5.Timing import *


class Adherence(FhirBaseModel):
    """This indicates how or if the device is being used.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept code: always | never | sometimes
    :param CodeableConcept reason: lost | stolen | prescribed | broken | burned | forgot
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "reason": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        code: "CodeableConcept" = None,
        reason: list["CodeableConcept"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.code = code
        self.reason = reason or []

    @classmethod
    def from_dict(cls, data: dict) -> "DeviceUsage":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "DeviceUsage":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class DeviceUsage(DomainResource):
    """A record of a device being used by a patient where the record is the result of a report from the patient or a clinician.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: External identifier for this record
    :param Reference basedOn: Fulfills plan, proposal or order
    :param str status: active | completed | not-done | entered-in-error +
    :param CodeableConcept category: The category of the statement - classifying how the statement is made
    :param Reference patient: Patient using device
    :param Reference derivedFrom: Supporting information
    :param Reference context: The encounter or episode of care that establishes the context for this device use statement
    :param Timing timingTiming: How often  the device was used
    :param Period timingPeriod: How often  the device was used
    :param str timingDateTime: How often  the device was used
    :param str dateAsserted: When the statement was made (and recorded)
    :param CodeableConcept usageStatus: The status of the device usage, for example always, sometimes, never. This is not the same as the status of the statement
    :param CodeableConcept usageReason: The reason for asserting the usage status - for example forgot, lost, stolen, broken
    :param Adherence adherence: How device is being used
    :param Reference informationSource: Who made the statement
    :param CodeableReference device: Code or Reference to device used
    :param CodeableReference reason: Why device was used
    :param CodeableReference bodySite: Target body site
    :param Annotation note: Addition details (comments, instructions)
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "basedOn": {"class_name": "Reference", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "patient": {"class_name": "Reference", "is_contained": False},
        "derivedFrom": {"class_name": "Reference", "is_contained": False},
        "context": {"class_name": "Reference", "is_contained": False},
        "timingTiming": {"class_name": "Timing", "is_contained": False},
        "timingPeriod": {"class_name": "Period", "is_contained": False},
        "usageStatus": {"class_name": "CodeableConcept", "is_contained": False},
        "usageReason": {"class_name": "CodeableConcept", "is_contained": False},
        "adherence": {"class_name": "Adherence", "is_contained": True},
        "informationSource": {"class_name": "Reference", "is_contained": False},
        "device": {"class_name": "CodeableReference", "is_contained": False},
        "reason": {"class_name": "CodeableReference", "is_contained": False},
        "bodySite": {"class_name": "CodeableReference", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        basedOn: list["Reference"] = None,
        status: "str" = None,
        category: list["CodeableConcept"] = None,
        patient: "Reference" = None,
        derivedFrom: list["Reference"] = None,
        context: "Reference" = None,
        timingTiming: "Timing" = None,
        timingPeriod: "Period" = None,
        timingDateTime: "str" = None,
        dateAsserted: "str" = None,
        usageStatus: "CodeableConcept" = None,
        usageReason: list["CodeableConcept"] = None,
        adherence: "Adherence" = None,
        informationSource: "Reference" = None,
        device: "CodeableReference" = None,
        reason: list["CodeableReference"] = None,
        bodySite: "CodeableReference" = None,
        note: list["Annotation"] = None,
    ):

        self.resourceType = "DeviceUsage"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.basedOn = basedOn or []
        self.status = status
        self.category = category or []
        self.patient = patient
        self.derivedFrom = derivedFrom or []
        self.context = context
        self.timingTiming = timingTiming
        self.timingPeriod = timingPeriod
        self.timingDateTime = timingDateTime
        self.dateAsserted = dateAsserted
        self.usageStatus = usageStatus
        self.usageReason = usageReason or []
        self.adherence = adherence
        self.informationSource = informationSource
        self.device = device
        self.reason = reason or []
        self.bodySite = bodySite
        self.note = note or []

    @classmethod
    def from_dict(cls, data: dict) -> "DeviceUsage":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "DeviceUsage":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for CareTeam. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.Annotation import *
from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.CodeableReference import *
from fhirmodels.R5.ContactPoint import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Period import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Resource import *
from fhirmodels.R5.Timing import *


class Participant(FhirBaseModel):
    """Identifies all people and organizations who are expected to be involved in the care team.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept role: Type of involvement
    :param Reference member: Who is involved
    :param Reference onBehalfOf: Organization of the practitioner
    :param Period coveragePeriod: When the member is generally available within this care team
    :param Timing coverageTiming: When the member is generally available within this care team
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "role": {"class_name": "CodeableConcept", "is_contained": False},
        "member": {"class_name": "Reference", "is_contained": False},
        "onBehalfOf": {"class_name": "Reference", "is_contained": False},
        "coveragePeriod": {"class_name": "Period", "is_contained": False},
        "coverageTiming": {"class_name": "Timing", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        role: "CodeableConcept" = None,
        member: "Reference" = None,
        onBehalfOf: "Reference" = None,
        coveragePeriod: "Period" = None,
        coverageTiming: "Timing" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.role = role
        self.member = member
        self.onBehalfOf = onBehalfOf
        self.coveragePeriod = coveragePeriod
        self.coverageTiming = coverageTiming

    @classmethod
    def from_dict(cls, data: dict) -> "CareTeam":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "CareTeam":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class CareTeam(DomainResource):
    """The Care Team includes all the people and organizations who plan to participate in the coordination and delivery of care.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: External Ids for this team
    :param str status: proposed | active | suspended | inactive | entered-in-error
    :param CodeableConcept category: Type of team
    :param str name: Name of the team, such as crisis assessment team
    :param Reference subject: Who care team is for
    :param Period period: Time period team covers
    :param Participant participant: Members of the team
    :param CodeableReference reason: Why the care team exists
    :param Reference managingOrganization: Organization responsible for the care team
    :param ContactPoint telecom: A contact detail for the care team (that applies to all members)
    :param Annotation note: Comments made about the CareTeam
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "period": {"class_name": "Period", "is_contained": False},
        "participant": {"class_name": "Participant", "is_contained": True},
        "reason": {"class_name": "CodeableReference", "is_contained": False},
        "managingOrganization": {"class_name": "Reference", "is_contained": False},
        "telecom": {"class_name": "ContactPoint", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        status: "str" = None,
        category: list["CodeableConcept"] = None,
        name: "str" = None,
        subject: "Reference" = None,
        period: "Period" = None,
        participant: list["Participant"] = None,
        reason: list["CodeableReference"] = None,
        managingOrganization: list["Reference"] = None,
        telecom: list["ContactPoint"] = None,
        note: list["Annotation"] = None,
    ):

        self.resourceType = "CareTeam"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.status = status
        self.category = category or []
        self.name = name
        self.subject = subject
        self.period = period
        self.participant = participant or []
        self.reason = reason or []
        self.managingOrganization = managingOrganization or []
        self.telecom = telecom or []
        self.note = note or []

    @classmethod
    def from_dict(cls, data: dict) -> "CareTeam":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "CareTeam":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for AdministrableProductDefinition. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.R4B.Attachment import *
from fhirmodels.R4B.BackboneElement import *
from fhirmodels.R4B.CodeableConcept import *
from fhirmodels.R4B.DomainResource import *
from fhirmodels.R4B.Duration import *
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.Identifier import *
from fhirmodels.R4B.Meta import *
from fhirmodels.R4B.Narrative import *
from fhirmodels.R4B.Quantity import *
from fhirmodels.R4B.Ratio import *
from fhirmodels.R4B.Reference import *
from fhirmodels.R4B.Resource import *


class Property(FhirBaseModel):
    """Characteristics e.g. a product's onset of action.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: A code expressing the type of characteristic
    :param CodeableConcept valueCodeableConcept: A value for the characteristic
    :param Quantity valueQuantity: A value for the characteristic
    :param str valueDate: A value for the characteristic
    :param bool valueBoolean: A value for the characteristic
    :param Attachment valueAttachment: A value for the characteristic
    :param CodeableConcept status: The status of characteristic e.g. assigned or pending
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "valueCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "valueQuantity": {"class_name": "Quantity", "is_contained": False},
        "valueAttachment": {"class_name": "Attachment", "is_contained": False},
        "status": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        valueCodeableConcept: "CodeableConcept" = None,
        valueQuantity: "Quantity" = None,
        valueDate: "str" = None,
        valueBoolean: "bool" = None,
        valueAttachment: "Attachment" = None,
        status: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.valueCodeableConcept = valueCodeableConcept
        self.valueQuantity = valueQuantity
        self.valueDate = valueDate
        self.valueBoolean = valueBoolean
        self.valueAttachment = valueAttachment
        self.status = status

    @classmethod
    def from_dict(cls, data: dict) -> "AdministrableProductDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "AdministrableProductDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class WithdrawalPeriod(FhirBaseModel):
    """A species specific time during which consumption of animal product is not appropriate.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept tissue: The type of tissue for which the withdrawal period applies, e.g. meat, milk
    :param Quantity value: A value for the time
    :param str supportingInformation: Extra information about the withdrawal period
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "tissue": {"class_name": "CodeableConcept", "is_contained": False},
        "value": {"class_name": "Quantity", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        tissue: "CodeableConcept" = None,
        value: "Quantity" = None,
        supportingInformation: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.tissue = tissue
        self.value = value
        self.supportingInformation = supportingInformation

    @classmethod
    def from_dict(cls, data: dict) -> "AdministrableProductDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "AdministrableProductDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class TargetSpecies(FhirBaseModel):
    """A species for which this route applies.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept code: Coded expression for the species
    :param WithdrawalPeriod withdrawalPeriod: A species specific time during which consumption of animal product is not appropriate
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "withdrawalPeriod": {"class_name": "WithdrawalPeriod", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        code: "CodeableConcept" = None,
        withdrawalPeriod: list["WithdrawalPeriod"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.code = code
        self.withdrawalPeriod = withdrawalPeriod or []

    @classmethod
    def from_dict(cls, data: dict) -> "AdministrableProductDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "AdministrableProductDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class RouteOfAdministration(FhirBaseModel):
    """The path by which the product is taken into or makes contact with the body. In some regions this is referred to as the licenced or approved route. RouteOfAdministration cannot be used when the 'formOf' product already uses MedicinalProductDefinition.route (and vice versa).:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept code: Coded expression for the route
    :param Quantity firstDose: The first dose (dose quantity) administered can be specified for the product
    :param Quantity maxSingleDose: The maximum single dose that can be administered
    :param Quantity maxDosePerDay: The maximum dose quantity to be administered in any one 24-h period
    :param Ratio maxDosePerTreatmentPeriod: The maximum dose per treatment period that can be administered
    :param Duration maxTreatmentPeriod: The maximum treatment period during which the product can be administered
    :param TargetSpecies targetSpecies: A species for which this route applies
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "firstDose": {"class_name": "Quantity", "is_contained": False},
        "maxSingleDose": {"class_name": "Quantity", "is_contained": False},
        "maxDosePerDay": {"class_name": "Quantity", "is_contained": False},
        "maxDosePerTreatmentPeriod": {"class_name": "Ratio", "is_contained": False},
        "maxTreatmentPeriod": {"class_name": "Duration", "is_contained": False},
        "targetSpecies": {"class_name": "TargetSpecies", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        code: "CodeableConcept" = None,
        firstDose: "Quantity" = None,
        maxSingleDose: "Quantity" = None,
        maxDosePerDay: "Quantity" = None,
        maxDosePerTreatmentPeriod: "Ratio" = None,
        maxTreatmentPeriod: "Duration" = None,
        targetSpecies: list["TargetSpecies"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.code = code
        self.firstDose = firstDose
        self.maxSingleDose = maxSingleDose
        self.maxDosePerDay = maxDosePerDay
        self.maxDosePerTreatmentPeriod = maxDosePerTreatmentPeriod
        self.maxTreatmentPeriod = maxTreatmentPeriod
        self.targetSpecies = targetSpecies or []

    @classmethod
    def from_dict(cls, data: dict) -> "AdministrableProductDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "AdministrableProductDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class AdministrableProductDefinition(DomainResource):
    """A medicinal product in the final form which is suitable for administering to a patient (after any mixing of multiple components, dissolution etc. has been performed).
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: An identifier for the administrable product
    :param str status: draft | active | retired | unknown
    :param Reference formOf: References a product from which one or more of the constituent parts of that product can be prepared and used as described by this administrable product
    :param CodeableConcept administrableDoseForm: The dose form of the final product after necessary reconstitution or processing
    :param CodeableConcept unitOfPresentation: The presentation type in which this item is given to a patient. e.g. for a spray - 'puff'
    :param Reference producedFrom: Indicates the specific manufactured items that are part of the 'formOf' product that are used in the preparation of this specific administrable form
    :param CodeableConcept ingredient: The ingredients of this administrable medicinal product. This is only needed if the ingredients are not specified either using ManufacturedItemDefiniton, or using by incoming references from the Ingredient resource
    :param Reference device: A device that is integral to the medicinal product, in effect being considered as an "ingredient" of the medicinal product
    :param Property property: Characteristics e.g. a product's onset of action
    :param RouteOfAdministration routeOfAdministration: The path by which the product is taken into or makes contact with the body
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "formOf": {"class_name": "Reference", "is_contained": False},
        "administrableDoseForm": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "unitOfPresentation": {"class_name": "CodeableConcept", "is_contained": False},
        "producedFrom": {"class_name": "Reference", "is_contained": False},
        "ingredient": {"class_name": "CodeableConcept", "is_contained": False},
        "device": {"class_name": "Reference", "is_contained": False},
        "property": {"class_name": "Property", "is_contained": True},
        "routeOfAdministration": {
            "class_name": "RouteOfAdministration",
            "is_contained": True,
        },
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        status: "str" = None,
        formOf: list["Reference"] = None,
        administrableDoseForm: "CodeableConcept" = None,
        unitOfPresentation: "CodeableConcept" = None,
        producedFrom: list["Reference"] = None,
        ingredient: list["CodeableConcept"] = None,
        device: "Reference" = None,
        property: list["Property"] = None,
        routeOfAdministration: list["RouteOfAdministration"] = None,
    ):

        self.resourceType = "AdministrableProductDefinition"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.status = status
        self.formOf = formOf or []
        self.administrableDoseForm = administrableDoseForm
        self.unitOfPresentation = unitOfPresentation
        self.producedFrom = producedFrom or []
        self.ingredient = ingredient or []
        self.device = device
        self.property = property or []
        self.routeOfAdministration = routeOfAdministration or []

    @classmethod
    def from_dict(cls, data: dict) -> "AdministrableProductDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "AdministrableProductDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()
